@@ -1,4 +1,4 @@
-# Copyright 2010-2020 Gentoo Authors
+# Copyright 2010-2021 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
 import bz2
@@ -9,7 +9,11 @@ import portage
 from itertools import permutations
 from portage import os
 from portage import shutil
-from portage.const import (GLOBAL_CONFIG_PATH, USER_CONFIG_PATH)
+from portage.const import (
+	GLOBAL_CONFIG_PATH,
+	PORTAGE_BIN_PATH,
+	USER_CONFIG_PATH,
+)
 from portage.process import find_binary
 from portage.dep import Atom, _repo_separator
 from portage.package.ebuild.config import config
@@ -44,7 +48,13 @@ class ResolverPlayground:
 	config_files = frozenset(("eapi", "layout.conf", "make.conf", "modules", "package.accept_keywords",
 		"package.keywords", "package.license", "package.mask", "package.properties",
 		"package.provided", "packages",
-		"package.unmask", "package.use", "package.use.aliases", "package.use.stable.mask",
+		"package.unmask",
+		"package.use",
+		"package.use.aliases",
+		"package.use.force",
+		"package.use.mask",
+		"package.use.stable.force",
+		"package.use.stable.mask",
 		"soname.provided",
 		"unpack_dependencies", "use.aliases", "use.force", "use.mask", "layout.conf"))
 
@@ -62,6 +72,27 @@ class ResolverPlayground:
 </pkgmetadata>
 """
 
+	portage_bin = (
+		'ebuild',
+		'egencache',
+		'emerge',
+		'emerge-webrsync',
+		'emirrordist',
+		'glsa-check',
+		'portageq',
+		'quickpkg',
+	)
+
+	portage_sbin = (
+		'archive-conf',
+		'dispatch-conf',
+		'emaint',
+		'env-update',
+		'etc-update',
+		'fixpackages',
+		'regenworld',
+	)
+
 	def __init__(self, ebuilds={}, binpkgs={}, installed={}, profile={}, repo_configs={}, \
 		user_config={}, sets={}, world=[], world_sets=[], distfiles={}, eclasses={},
 		eprefix=None, targetroot=False, debug=False):
@@ -79,6 +110,14 @@ class ResolverPlayground:
 			# EPREFIX/bin is used by fake true_binaries. Real binaries goes into EPREFIX/usr/bin
 			eubin = os.path.join(self.eprefix, "usr", "bin")
 			ensure_dirs(eubin)
+			for x in self.portage_bin:
+				os.symlink(os.path.join(PORTAGE_BIN_PATH, x), os.path.join(eubin, x))
+
+			eusbin = os.path.join(self.eprefix, "usr", "sbin")
+			ensure_dirs(eusbin)
+			for x in self.portage_sbin:
+				os.symlink(os.path.join(PORTAGE_BIN_PATH, x), os.path.join(eusbin, x))
+
 			essential_binaries = (
 				"awk",
 				"basename",
@@ -134,6 +173,7 @@ class ResolverPlayground:
 		# this because tests should be self-contained such that
 		# the "real" value of portage.const.EPREFIX is entirely
 		# irrelevant (see bug #492932).
+		self._orig_eprefix = portage.const.EPREFIX
 		portage.const.EPREFIX = self.eprefix.rstrip(os.sep)
 
 		self.eroot = self.eprefix + os.sep
@@ -639,6 +679,9 @@ class ResolverPlayground:
 			print("\nEROOT=%s" % self.eroot)
 		else:
 			shutil.rmtree(self.eroot)
+		if hasattr(self, '_orig_eprefix'):
+			portage.const.EPREFIX = self._orig_eprefix
+
 
 class ResolverPlaygroundTestCase:
 
